@@ -45,6 +45,7 @@ class Site:
     # Vars that will be passed into the render functions
     site_vars: dict = {"SITE_TITLE": "Untitled Site", "SITE_URL": "https://example.com"}
 
+
     engine: typing.Type[Environment] = Environment(loader=FileSystemLoader("templates"))
     """``Engine`` to generate web pages"""
 
@@ -55,7 +56,7 @@ class Site:
         rprint(pad)
 
         if static:
-            self.render_static(static)
+            self.render_static(directory=static)
 
     def render_collection(self, collection: typing.Type[Collection]) -> None:
         """Add a class to your ``self.collections``
@@ -95,6 +96,7 @@ class Site:
         for page in _collection.pages:
             page.render(
                 path=collection_path,
+                engine=self.engine,
                 **self.site_vars,
             )
             p.update(rendering_pages, advance=1)
@@ -111,7 +113,7 @@ class Site:
                 link=self.site_vars["SITE_URL"],
                 pages=_collection.pages,
             )
-            feed.render(path=self.path, **self.site_vars, **collection_vars)
+            feed.render(path=self.path, engine=self.engine, **self.site_vars, **collection_vars)
             p.update(create_feed, completed=1)
 
         p.update(build_collection, advance=1)
@@ -123,6 +125,7 @@ class Site:
             )
             render_archives(
                 path=collection_path,
+                engine=self.engine,
                 archive=_collection.archives,
                 **self.site_vars,
             )
@@ -153,6 +156,7 @@ class Site:
                 for subgroup in subgroups:
                     render_archives(
                         path=subcollection_path,
+                        engine=self.engine,
                         archive=subgroup,
                         **self.site_vars,
                         **collection_vars,
@@ -166,10 +170,10 @@ class Site:
     def render_page(self, page) -> None:
         """Create a Page object and add it to self.routes"""
         with p:
-
+            
             _page = page(**self.site_vars)
-            _page.render(path=self.path, **page.__dict__)
+            _page.render(path=self.path, engine=self.engine, **page.__dict__)
 
     def render_static(self, directory) -> None:
         """Copies a Static Directory to the output folder"""
-        return shutil.copytree(directory, self.path / directory, dirs_exist_ok=True)
+        return shutil.copytree(directory, self.path / Path(directory).name, dirs_exist_ok=True)
